//+------------------------------------------------------------------+
//|                                    WeeklyScalping LinesReset.mq4 |
//|                                                         SwingMan |
//|                                               soc607@t-online.de |
//+------------------------------------------------------------------+
#property copyright "SwingMan"
#property link      "soc607@t-online.de"

#property indicator_chart_window

#property indicator_buffers 4
//---- colors
#property indicator_color1 Teal
#property indicator_color2 Teal
#property indicator_color3 LightSalmon
#property indicator_color4 LightSalmon


//---- extern parameters ---------------------------------------------
extern int Period_ATRweekly  = 34;
extern double factor_EntryOffset  = 0.20;
extern double factor_StopLoss   = 0.60;
extern double factor_Target = 2.0;
//--------------------------------------------------------------------

//---- variables
int thisTimeFrame, upperTimeFrame;
int maxPeriod;
//---- Buffers
double CloseUpperTimeFrame[];
double LongStop[], LongTarget[];
double ShortStop[], ShortTarget[];
double BarRange[];

//+------------------------------------------------------------------+
//| Custom indicator initialization function                         |
//+------------------------------------------------------------------+
int init()
{
   thisTimeFrame = Period();
   upperTimeFrame = PERIOD_W1;
   if (thisTimeFrame > upperTimeFrame) return(0);
   
   ArraySetAsSeries(BarRange, true);
   ArraySetAsSeries(CloseUpperTimeFrame, true);
   
//---- indicators
   string sName = "WeeklyScalping LinesReset";
   IndicatorShortName(sName);
   //Comment(sName);
//----
   SetIndexBuffer(0,LongStop);
   SetIndexBuffer(1,LongTarget);
   SetIndexStyle(0,DRAW_LINE,STYLE_SOLID,2); // long
   SetIndexStyle(1,DRAW_LINE,STYLE_SOLID,2);   
   SetIndexLabel(0,"LongStopReset");
   SetIndexLabel(1,"LongTargetReset");
   
   
   SetIndexBuffer(2,ShortStop);              // short
   SetIndexBuffer(3,ShortTarget);
   SetIndexStyle(2,DRAW_LINE,STYLE_SOLID,2);
   SetIndexStyle(3,DRAW_LINE,STYLE_SOLID,2);
   SetIndexLabel(2,"ShortStopReset");
   SetIndexLabel(3,"ShortTargetReset");
    
//----         
   maxPeriod = Period_ATRweekly;
   SetIndexDrawBegin(0, maxPeriod);
   SetIndexDrawBegin(1, maxPeriod);
   
   return(0);
}

int deinit()
{ return(0); }

//+------------------------------------------------------------------+
//| Custom indicator iteration function                              |
//+------------------------------------------------------------------+
int start()
{
if (thisTimeFrame > upperTimeFrame) return(0);
int i,y,ind, limit ;
   
   ArrayResize(BarRange, Bars);
   ArrayResize(CloseUpperTimeFrame, Bars);

   int counted_bars = IndicatorCounted();
   if(counted_bars > 0) counted_bars--;
   limit = Bars - counted_bars;
   
   //---- Upper TimeFrame ............................................
   datetime TimeArray[];   
   ArrayCopySeries(TimeArray,MODE_TIME,Symbol(),upperTimeFrame);   
   
   for(i=0, y=0; i<limit; i++)  {
      if (Time[i] < TimeArray[y]) y++; 
   
      /***********************************************************   
      Add your main indicator loop below.  You can reference an existing
         indicator with its iName  or iCustom.
      Rule 1:  Add extern inputs above for all neccesary values   
      Rule 2:  Use 'TimeFrame' for the indicator timeframe
      Rule 3:  Use 'y' for the indicator's shift value
      ***********************************************************/  

      BarRange[i] = iATR(NULL,upperTimeFrame, Period_ATRweekly, y+1);     
      CloseUpperTimeFrame[i]=iClose(NULL,upperTimeFrame,y+1); 
      // Trading levels
      double dEntryOffset = NormalizeDouble(BarRange[i] * factor_EntryOffset, Digits);
      double dStopLoss    = NormalizeDouble(dEntryOffset * factor_StopLoss, Digits);
      double dTarget      = NormalizeDouble(dEntryOffset * factor_Target, Digits);

      LongStop[i]  = CloseUpperTimeFrame[i] - dStopLoss;
      LongTarget[i]= CloseUpperTimeFrame[i] + dTarget;
      
      ShortStop[i]  = CloseUpperTimeFrame[i] + dStopLoss;
      ShortTarget[i]= CloseUpperTimeFrame[i] - dTarget;
   }
//----
   return(0);
}
//+------------------------------------------------------------------+